SET QUOTED_IDENTIFIER ON

-- Create Databases
CREATE DATABASE INV_SQL

-- Create Tables
USE INV_SQL
CREATE TABLE DBO."Products"(
   "ID_PRODUCTS" INT IDENTITY,
   "ProductNumber" INT NOT NULL,
   "ProductSKU" VARCHAR(10),
   "Description" VARCHAR(35) NOT NULL,
   "Price" DECIMAL(7,2),
   "QuantityInStock" DECIMAL(7,2),
   "ReOrderQuantity" DECIMAL(7,2),
   "Cost" DECIMAL(7,2),
   "PictureFile" VARCHAR(64),
   CONSTRAINT "PK_PRODUCTS" PRIMARY KEY ("ID_PRODUCTS"),
   CONSTRAINT "KeyProductNumber" UNIQUE ("ProductNumber"),
   CONSTRAINT "KeyProductSku" UNIQUE ("ProductSKU"))
CREATE INDEX "KeyDescription" ON DBO."Products"("Description")

CREATE TABLE DBO."Vendors"(
   "ID_VENDORS" INT IDENTITY,
   "ID_ZIPCODES" INT,
   "VendorNumber" INT,
   "VendorName" VARCHAR(35),
   "Address1" VARCHAR(35),
   "Address2" VARCHAR(35),
   "City" VARCHAR(25),
   "State" VARCHAR(2),
   "ZipCode" VARCHAR(10),
   "PhoneNumber" DECIMAL(10,0),
   CONSTRAINT "PK_VENDORS" PRIMARY KEY ("ID_VENDORS"),
   CONSTRAINT "KeyVendorNumber" UNIQUE ("VendorNumber"))
CREATE INDEX "FK_ZIPCODES_VENDORS" ON DBO."Vendors"("ID_ZIPCODES")
CREATE INDEX "KeyVendorName" ON DBO."Vendors"("VendorName")

CREATE TABLE DBO."InvHist"(
   "ID_INVHIST" INT IDENTITY,
   "ID_VENDORS" INT,
   "ID_PRODUCTS" INT,
   "Date" DATETIME NOT NULL DEFAULT (getdate()),
   "Type" VARCHAR(7) NOT NULL,
   "ProductNumber" INT,
   "Quantity" DECIMAL(7,2) NOT NULL,
   "VendorNumber" INT,
   "Cost" DECIMAL(7,2),
   "Notes" VARCHAR(50),
   CONSTRAINT "PK_INVHIST" PRIMARY KEY ("ID_INVHIST"))
CREATE INDEX "FK_VENDORS_INVHIST" ON DBO."InvHist"("ID_VENDORS")
CREATE INDEX "FK_PRODUCTS_INVHIST" ON DBO."InvHist"("ID_PRODUCTS")
CREATE INDEX "KeyProductNumberVendorDate" ON DBO."InvHist"("ProductNumber","VendorNumber","Date")
CREATE INDEX "KeyProdNumberDate" ON DBO."InvHist"("ProductNumber","Date")
CREATE INDEX "KeyVendorNumberDate" ON DBO."InvHist"("VendorNumber","Date")

CREATE TABLE DBO."ZipCodes"(
   "ID_ZIPCODES" INT IDENTITY,
   "ZIP" VARCHAR(10),
   "CITY" VARCHAR(25),
   "STATE" VARCHAR(2),
   CONSTRAINT "PK_ZIPCODES" PRIMARY KEY ("ID_ZIPCODES"))
CREATE INDEX "KEYZIPCODE" ON DBO."ZipCodes"("ZIP")
CREATE INDEX "KEYZIPCITY" ON DBO."ZipCodes"("CITY")

ALTER TABLE DBO."InvHist" ADD
   CONSTRAINT "FK_PRODUCTS_INVHIST" FOREIGN KEY ("ID_PRODUCTS")
   REFERENCES DBO."Products"("ID_PRODUCTS")

ALTER TABLE DBO."InvHist" ADD
   CONSTRAINT "FK_VENDORS_INVHIST" FOREIGN KEY ("ID_VENDORS")
   REFERENCES DBO."Vendors"("ID_VENDORS")

ALTER TABLE DBO."Vendors" ADD
   CONSTRAINT "FK_ZIPCODES_VENDORS" FOREIGN KEY ("ID_ZIPCODES")
   REFERENCES DBO."ZipCodes"("ID_ZIPCODES")


-----------------------------------------------------
CREATE TABLE DBO."Dummy"(
   "dummy_col" INT )
